==> apache-sedona-1.2.0-incubating-src.tar.gz: apache-sedona-1.2.0-incubating-src/docs/setup/overview.md <==
# Who are using Sedona? 

[<img src="https://www.dataiku.com/static/img/partners/LOGO-Blue-DME-PNG-3.png" width="100">](https://www.bluedme.com/) &nbsp;&nbsp; 
[<img src="https://images.ukfast.co.uk/comms/news/businesscloud/photos/14-08-2018/gyana.jpg" width="100">](https://www.gyana.co.uk/) &nbsp;&nbsp; 
[<img src="https://149448277.v2.pressablecdn.com/wp-content/uploads/2021/03/guy-carpenter-logo-1.png" width="80">](https://guycarp.com/) &nbsp;&nbsp;[<img src="../../image/meituan-bike.png" width="170">](http://t8.pub) and more...

|Download statistics| **Maven** | **PyPI** | **CRAN** |
|:-------------:|:------------------:|:--------------:|:---------:|
| Apache Sedona |         80k/month        |[![Downloads](https://static.pepy.tech/personalized-badge/apache-sedona?period=month&units=international_system&left_color=black&right_color=brightgreen&left_text=downloads/month)](https://pepy.tech/project/apache-sedona) [![Downloads](https://static.pepy.tech/personalized-badge/apache-sedona?period=total&units=international_system&left_color=black&right_color=brightgreen&left_text=total%20downloads)](https://pepy.tech/project/apache-sedona)|[![](https://cranlogs.r-pkg.org/badges/apache.sedona?color=brightgreen)](https://cran.r-project.org/package=apache.sedona) [![](https://cranlogs.r-pkg.org/badges/grand-total/apache.sedona?color=brightgreen)](https://cran.r-project.org/package=apache.sedona)|
|    Archived GeoSpark releases   |300k/month|[![Downloads](https://static.pepy.tech/personalized-badge/geospark?period=month&units=international_system&left_color=black&right_color=brightgreen&left_text=downloads/month)](https://pepy.tech/project/geospark)[![Downloads](https://static.pepy.tech/personalized-badge/geospark?period=total&units=international_system&left_color=black&right_color=brightgreen&left_text=total%20downloads)](https://pepy.tech/project/geospark)|           |

# What can Sedona do?

## Distributed spatial datasets
- [x] Spatial RDD on Spark
- [x] Spatial DataFrame/SQL on Spark
- [x] Spatial DataStream on Flink
- [x] Spatial Table/SQL on Flink

## Complex spatial objects
- [x] Vector geometries / trajectories
- [x] Raster images with Map Algebra
- [x] Various input formats: CSV, TSV, WKT, WKB, GeoJSON, Shapefile, GeoTIFF, NetCDF/HDF

## Distributed spatial queries
- [x] Spatial query: range query, range join query, distance join query, K Nearest Neighbor query
- [x] Spatial index: R-Tree, Quad-Tree

## Rich spatial analytics tools 
- [x] Coordinate Reference System / Spatial Reference System Transformation
- [x] High resolution map generation: [Visualize Spatial DataFrame/RDD](../../tutorial/viz)
- [x] Apache Zeppelin integration
- [x] Support Scala, Java, Python, R

==> apache-sedona-1.3.1-incubating-src.tar.gz: apache-sedona-1.3.1-incubating-src/docs/setup/overview.md <==
# Download statistics

|| **Maven** | **PyPI** | **CRAN** |
|:-------------:|:------------------:|:--------------:|:---------:|
| Apache Sedona |         80k/month        |[![Downloads](https://static.pepy.tech/personalized-badge/apache-sedona?period=month&units=international_system&left_color=black&right_color=brightgreen&left_text=downloads/month)](https://pepy.tech/project/apache-sedona) [![Downloads](https://static.pepy.tech/personalized-badge/apache-sedona?period=total&units=international_system&left_color=black&right_color=brightgreen&left_text=total%20downloads)](https://pepy.tech/project/apache-sedona)|[![](https://cranlogs.r-pkg.org/badges/apache.sedona?color=brightgreen)](https://cran.r-project.org/package=apache.sedona) [![](https://cranlogs.r-pkg.org/badges/grand-total/apache.sedona?color=brightgreen)](https://cran.r-project.org/package=apache.sedona)|
|    Archived GeoSpark releases   |300k/month|[![Downloads](https://static.pepy.tech/personalized-badge/geospark?period=month&units=international_system&left_color=black&right_color=brightgreen&left_text=downloads/month)](https://pepy.tech/project/geospark)[![Downloads](https://static.pepy.tech/personalized-badge/geospark?period=total&units=international_system&left_color=black&right_color=brightgreen&left_text=total%20downloads)](https://pepy.tech/project/geospark)|           |

# What can Sedona do?

## Distributed spatial datasets
- [x] Spatial RDD on Spark
- [x] Spatial DataFrame/SQL on Spark
- [x] Spatial DataStream on Flink
- [x] Spatial Table/SQL on Flink

## Complex spatial objects
- [x] Vector geometries / trajectories
- [x] Raster images with Map Algebra
- [x] Various input formats: CSV, TSV, WKT, WKB, GeoJSON, Shapefile, GeoTIFF, NetCDF/HDF

## Distributed spatial queries
- [x] Spatial query: range query, range join query, distance join query, K Nearest Neighbor query
- [x] Spatial index: R-Tree, Quad-Tree

## Rich spatial analytics tools 
- [x] Coordinate Reference System / Spatial Reference System Transformation
- [x] High resolution map generation: [Visualize Spatial DataFrame/RDD](../../tutorial/viz)
- [x] Apache Zeppelin integration
- [x] Support Scala, Java, Python, R
